import { HttpClient } from '@angular/common/http';
import { DomSanitizer } from '@angular/platform-browser';
import { Observable, OperatorFunction } from 'rxjs';
import { FileStorageConfig } from './file-storage.config';
export declare class FileStorageService {
    private httpClient;
    private fileStorageConfig;
    private sanitizer;
    constructor(httpClient: HttpClient, fileStorageConfig: FileStorageConfig, sanitizer: DomSanitizer);
    /**
     * Realiza o download do storage da logistica e transforma em um objeto do navegador
     * @param id O id do arquivo
     */
    getAsSafeUrl(id: string): Observable<import("@angular/platform-browser").SafeUrl>;
    /**
     * Realiza o download do storage da logistica
     * @param id O id do arquivo
     */
    get(id: string): Observable<Blob>;
    /**
     * Realiza o download de um zip do storage da logistica
     * @param zipName O nome do arquivo zip
     * @param filesId O ids dos arquivos
     *
     */
    zip(zipName: string, filesId: string[]): Observable<Blob>;
    /**
     * Realiza o download de um zip do storage da logistica e transforma em um objeto do navegador
     * @param zipName O nome do arquivo zip
     * @param filesId O ids dos arquivos
     *
     */
    zipAsSafeUrl(zipName: string, filesId: string[]): Observable<import("@angular/platform-browser").SafeUrl>;
    private getZipUrl;
    /**
     * Realiza o download de um arquivo da internet
     * @param url A url do arquivo
     */
    download(url: string): Observable<Blob>;
}
/**
 * Operador de pipe para transformar um blob em um objeto de url, utilizável pelo navegador.
 */
export declare function blobToObjectUrl(): OperatorFunction<Blob, string>;
